@@ -1,6 +1,6 @@
 # 2016. 1. 10 by Hans Roh hansroh@gmail.com
 
-__version__ = "0.2.3.26"
+__version__ = "0.2.13.4"
 
 version_info = tuple (map (lambda x: not x.isdigit () and x or int (x),  __version__.split (".")))
 
@@ -13,15 +13,16 @@ from .termcolor import tc
 import subprocess as subprocess_
 import asyncio as asyncio_
 from asyncio.tasks import Task
-from .aio import aio
+import sys
+if sys.version_info >= (3, 5):
+    from .aio import aio
 
 # for lower version compatibles -------------
-from . import deco as versioning
+from . import annotations as versioning
+deco = versioning
 class udict: pass
 # end of compatibles -----------------------
 
-from .argopt import options, add_option, add_options
-
 # abbreviations ----------------------------------------------------
 def tqdm (iterable, desc = "", color = None, **karg):
     if color:
@@ -29,24 +30,32 @@ def tqdm (iterable, desc = "", color = None, **karg):
     else:
         return tqdm_ (iterable, desc, **karg)
 
-def threading (workers = 1):
+def tpool (workers = 1):
     return concurrent.futures.ThreadPoolExecutor (max_workers = workers)
+threading = tpool
 
-def processing (workers = 1):
+def ppool (workers = 1):
     return concurrent.futures.ProcessPoolExecutor (max_workers = workers)
-    
+processing = ppool
+
+def ppool2 (workers = 1):
+    return Pool (workers)
+processing2 = ppool2
+
 def subprocessing (cmd_or_func, *args):
     if isinstance (cmd_or_func, (list, tuple, str)):
-        res = subprocess_.run (cmd_or_func, shell = True, stdout = subprocess_.PIPE, stderr = subprocess_.PIPE)    
+        res = subprocess_.run (cmd_or_func, shell = True, stdout = subprocess_.PIPE, stderr = subprocess_.PIPE)
         out, err = res.stdout.decode ("utf8"), res.stderr.decode ("utf8")
         if err:
             raise RuntimeError (err)
         return out
-    
+
     with Pool (1) as p:
         return p.apply (cmd_or_func, args)
-        
+
 def waitf (futures, timeout = None):
+    if not futures:
+        return [], []
     # wait Futures or async Tasks
     if isinstance (futures [0], Task):
         return aio.wait (futures, timeout = timeout)
@@ -56,6 +65,6 @@ def waitf (futures, timeout = None):
 def wait (futures, timeout = None):
     dones, undones = waitf (futures)
     return timeout is None and dones or (dones, undones)
-    
+
 def as_completed (futures):
     return concurrent.futures.as_completed (futures)
