@@ -1,5 +1,9 @@
 import os, sys
-from setproctitle import setproctitle
+try:
+    from setproctitle import setproctitle
+except ImportError:
+    setproctitle = None
+
 from . import daemon
 import time
 from .. import pathtool
@@ -13,7 +17,7 @@ class Service:
         self.working_dir = working_dir
         self.lockpath = lockpath or working_dir
         self.win32service = win32service        
-        setproctitle (name)
+        setproctitle and setproctitle (name)
         pathtool.mkdir (working_dir)
         if lockpath:
             pathtool.mkdir (lockpath)
@@ -23,9 +27,9 @@ class Service:
         if os.name == "nt":
             set_service_config (['start'])
         else:    
-            from . import Daemonizer
+            from . import Daemonizer            
             if not Daemonizer (self.working_dir, self.name, lockpath = self.lockpath).runAsDaemon ():
-                pid = daemon.status (self.lockpath, self.name)
+                pid = daemon.status (self.lockpath, self.name)                
                 print ("{} {}".format (tc.debug (self.name), tc.error ("[already running:{}]".format (pid))))
                 sys.exit ()
             
